The function allows the integration of a given ppm vector with a specific width.
Arguments
- samples
A nmr_dataset object
- peak_pos_ppm
The peak positions, in ppm
- peak_width_ppm
The peak widths (or a single peak width for all peaks)
- ...
Arguments passed on to
nmr_integrate_regionsregionsA named list. Each element of the list is a region, given as a named numeric vector of length two with the range to integrate. The name of the region will be the name of the column
fix_baselineA logical. If
TRUEit removes the baseline. See details belowexcluded_regions_as_zeroA logical. It determines the behaviour of the integration when integrating regions that have been excluded. If
TRUE, it will treat those regions as zero. IfFALSE(the default) it will return NA values.If
fix_baselineisTRUE, then the region boundaries are used to estimate a baseline. The baseline is estimated "connecting the boundaries with a straight line". Only when the spectrum is above the baseline the area is integrated (negative contributions due to the baseline estimation are ignored).set_negative_areas_to_zeroA logical. Ignored if
fix_baselineisFALSE. When set toTRUEnegative areas are set to zero.
See also
Other peak integration functions:
Pipelines,
get_integration_with_metadata(),
nmr_identify_regions_blood(),
nmr_identify_regions_cell(),
nmr_identify_regions_urine(),
nmr_integrate_regions()
Other nmr_dataset_1D functions:
[.nmr_dataset_1D(),
format.nmr_dataset_1D(),
get_integration_with_metadata(),
is.nmr_dataset_1D(),
nmr_integrate_regions(),
nmr_meta_add(),
nmr_meta_export(),
nmr_meta_get(),
nmr_meta_get_column(),
nmr_ppm_resolution(),
print.nmr_dataset_1D()